pub struct CommandScopeRegistry { /* private fields */ }Expand description
Store the scope graph and provide methods for querying it.
Implementations
Sourceimpl CommandScopeRegistry
impl CommandScopeRegistry
Sourcepub fn add_scope<S: Into<String>>(&mut self, scope: S)
pub fn add_scope<S: Into<String>>(&mut self, scope: S)
Add a scope to the registry.
Example
use chunkedge_command::CommandScopeRegistry;
let mut registry = CommandScopeRegistry::new();
// creates two nodes. "chunkedge" and "command" with an edge from "chunkedge" to "command"
registry.add_scope("chunkedge.command");
// creates one node. "chunkedge.command.tp" with an edge from "chunkedge.command" to
// "chunkedge.command.tp"
registry.add_scope("chunkedge.command.tp");
// the root node is always present
assert_eq!(registry.scope_count(), 4);Sourcepub fn remove_scope(&mut self, scope: &str)
pub fn remove_scope(&mut self, scope: &str)
Remove a scope from the registry.
Example
use chunkedge_command::CommandScopeRegistry;
let mut registry = CommandScopeRegistry::new();
registry.add_scope("chunkedge.command");
registry.add_scope("chunkedge.command.tp");
assert_eq!(registry.scope_count(), 4);
registry.remove_scope("chunkedge.command.tp");
assert_eq!(registry.scope_count(), 3);Sourcepub fn grants(&self, scope: &str, other: &str) -> bool
pub fn grants(&self, scope: &str, other: &str) -> bool
Check if a scope grants another scope.
Example
use chunkedge_command::CommandScopeRegistry;
let mut registry = CommandScopeRegistry::new();
registry.add_scope("chunkedge.command");
registry.add_scope("chunkedge.command.tp");
assert!(registry.grants("chunkedge.command", "chunkedge.command.tp")); // command implies tp
assert!(!registry.grants("chunkedge.command.tp", "chunkedge.command")); // tp does not imply commandSourcepub fn any_grants(&self, scopes: &Vec<&str>, other: &str) -> bool
pub fn any_grants(&self, scopes: &Vec<&str>, other: &str) -> bool
do any of the scopes in the list grant the other scope?
Example
use chunkedge_command::CommandScopeRegistry;
let mut registry = CommandScopeRegistry::new();
registry.add_scope("chunkedge.command");
registry.add_scope("chunkedge.command.tp");
registry.add_scope("chunkedge.admin");
assert!(registry.any_grants(
&vec!["chunkedge.admin", "chunkedge.command"],
"chunkedge.command.tp"
));Sourcepub fn link(&mut self, scope: &str, other: &str)
pub fn link(&mut self, scope: &str, other: &str)
Create a link between two scopes so that one implies the other. It will add them if they don’t exist.
Example
use chunkedge_command::CommandScopeRegistry;
let mut registry = CommandScopeRegistry::new();
registry.add_scope("chunkedge.command.tp");
registry.link("chunkedge.admin", "chunkedge.command");
assert!(registry.grants("chunkedge.admin", "chunkedge.command"));
assert!(registry.grants("chunkedge.admin", "chunkedge.command.tp"));Sourcepub fn scope_count(&self) -> usize
pub fn scope_count(&self) -> usize
Get the number of scopes in the registry.